<?php

namespace Drupal\laravel_helpers\Service;

use Drupal\Core\Extension\ModuleExtensionList;
use Illuminate\Translation\ArrayLoader;
use Illuminate\Translation\Translator;
use Illuminate\Validation\Factory as ValidatorFactory;
use Illuminate\Validation\Validator;

/**
 * The Laravel validator service.
 */
class Validators {

  /**
   * The Laravel validator.
   */
  protected ValidatorFactory $validator;

  /**
   * The module extension list.
   */
  protected ModuleExtensionList $extensionList;

  /**
   * Construct for Laravel validator.
   *
   * @param \Drupal\Core\Extension\ModuleExtensionList $extension_list
   *   The extension list.
   */
  public function __construct(ModuleExtensionList $extension_list) {
    $this->extensionList = $extension_list;
    $loader = new ArrayLoader();
    $defaultMessages = require_once DRUPAL_ROOT . '/' . $this->extensionList->getPath('laravel_helpers') . '/src/validation.php';
    $loader->addMessages('en', 'validation', (array) $defaultMessages);
    $translator = new Translator($loader, 'en');
    $this->validator = new ValidatorFactory($translator);
  }

  /**
   * Validate the data.
   *
   * @param array $data
   *   The array of data.
   * @param array $rules
   *   The array of rules.
   * @param array $messages
   *   The array of messages.
   * @param array $attributes
   *   The array of attributes.
   *
   * @return \Illuminate\Validation\Validator
   *   The validator result.
   */
  public function validate(array $data, array $rules, array $messages = [], array $attributes = []): Validator {
    return $this->validator->make($data, $rules, $messages, $attributes);
  }

}
